@@ -4,11 +4,11 @@ package Linux::DesktopFiles;
 # The best uses of this module is to generate real
 # time menus, based on the content of desktop files.
 
-#use 5.014;
+use 5.014;
 #use strict;
 #use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 sub new {
     my ($class, %opts) = @_;
@@ -253,7 +253,7 @@ sub get_desktop_files {
 sub parse {
     my ($self, $file_data, @desktop_files) = @_;
 
-    foreach my $desktop_file(@desktop_files) {
+    foreach my $desktop_file (@desktop_files) {
 
         if (defined $self->{skip_filename_re}) {
             substr($desktop_file, rindex($desktop_file, '/') + 1) =~ /$self->{skip_filename_re}/o && next;
@@ -276,6 +276,9 @@ sub parse {
             next if exists $self->{true_values}{$info{Hidden}};
         }
 
+        # If no 'Name' enrty is defined, create one with the name of the file
+        $info{Name} //= substr($desktop_file, rindex($desktop_file, '/') + 1, -8);
+
         (
          my @categories =
            grep { exists $self->{categories}{$_} }
@@ -331,8 +334,7 @@ sub parse {
             }
         }
         elsif ($self->{keep_unknown_categories}) {
-            push @{$file_data->{$self->{unknown_category_key}}},
-              {map { $_ => $info{$_} } @{$self->{keys_to_keep}}};
+            push @{$file_data->{$self->{unknown_category_key}}}, {map { $_ => $info{$_} } @{$self->{keys_to_keep}}};
         }
     }
 }
@@ -632,13 +634,17 @@ This function is equivalent with:
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/trizen/Linux-DesktopFiles>
+
 =head1 AUTHOR
 
 Daniel "Trizen" Șuteu, E<lt>trizenx@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2013, 2015
+Copyright (C) 2012-2016
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.14.2 or,
